@@ -1,14 +1,13 @@
 import logging
 import time
 from collections import UserList
-from datetime import date, datetime
+from datetime import date
 from random import random
 from typing import Callable, List
 
-import httplib2
-from apiclient import discovery
 from apiclient.errors import HttpError
-from oauth2client.client import OAuth2Credentials
+
+from api_connectors.integrations.google_base import GoogleBase
 
 
 class GoogleListResponse(UserList):
@@ -26,7 +25,7 @@ class GoogleListResponse(UserList):
         self.others = api_response
 
 
-class GoogleAnalyticsAPI_V4:
+class GoogleAnalyticsAPI_V4(GoogleBase):
     """ Google Analytics API is a proxy sub-library for an origin Python API library of Google.
         So it is rather different from other APIs.
 
@@ -35,35 +34,8 @@ class GoogleAnalyticsAPI_V4:
         For now, here supports only Core API v3
         Documentation: https://developers.google.com/analytics/devguides/reporting/core/v3?hl=ru
     """
-
-    def __init__(self, credentials: dict):
-        if isinstance(credentials['token_expiry'], str):
-            token_expiry = datetime.strptime(credentials['token_expiry'], '%Y-%m-%dT%H:%M:%SZ')
-        else:
-            token_expiry = credentials['token_expiry']
-
-        self.oauth_creds = OAuth2Credentials(
-            credentials['access_token'],
-            credentials['client_id'],
-            credentials['client_secret'],
-            credentials['refresh_token'],
-            token_expiry,
-            credentials['token_uri'],
-            credentials['user_agent'],
-            revoke_uri=credentials.get('revoke_uri', None),
-            id_token=credentials.get('id_token', None),
-            token_response=credentials.get('token_response', None)
-        )
-
-        self.oauth_creds.invalid = credentials['invalid']
-        self.refresh()
-        http_auth = self.oauth_creds.authorize(httplib2.Http(timeout=360))
-        self.client = discovery.build('analyticsreporting', 'v4', http=http_auth)
-
-    def refresh(self):
-        if self.oauth_creds.access_token_expired:
-            http = httplib2.Http(timeout=360)
-            self.oauth_creds.refresh(http)
+    resource_name = 'analyticsreporting'
+    version = 'v4'
 
     def request_processing(self, call_request: Callable):
         """ Performs handling the 500 errors """
@@ -157,7 +129,7 @@ class GoogleAnalyticsAPI_V4:
                     break
 
 
-class GoogleAnalyticsAPI_V3:
+class GoogleAnalyticsAPI_V3(GoogleBase):
     """ Google Analytics API is a proxy sub-library for an origin Python API library of Google.
         So it is rather different from other APIs.
 
@@ -166,30 +138,8 @@ class GoogleAnalyticsAPI_V3:
         For now, here supports only Core API v3
         Documentation: https://developers.google.com/analytics/devguides/reporting/core/v3?hl=ru
     """
-
-    def __init__(self, credentials: dict):
-        self.oauth_creds = OAuth2Credentials(
-            credentials['access_token'],
-            credentials['client_id'],
-            credentials['client_secret'],
-            credentials['refresh_token'],
-            credentials['token_expiry'],
-            credentials['token_uri'],
-            credentials['user_agent'],
-            revoke_uri=credentials.get('revoke_uri', None),
-            id_token=credentials.get('id_token', None),
-            token_response=credentials.get('token_response', None)
-        )
-
-        self.oauth_creds.invalid = credentials['invalid']
-        self.refresh()
-        http_auth = self.oauth_creds.authorize(httplib2.Http(timeout=360))
-        self.client = discovery.build('analytics', 'v3', http=http_auth)
-
-    def refresh(self):
-        if self.oauth_creds.access_token_expired:
-            http = httplib2.Http(timeout=360)
-            self.oauth_creds.refresh(http)
+    resource_name = 'analytics'
+    version = 'v3'
 
     def list_accounts(self):
         response = self.client.management().accounts().list().execute()
